diff --git a/Telegrator/Filters/CommandAlliasFilter.cs b/Telegrator/Filters/CommandAliasFilter.cs
similarity index 100%
rename from Telegrator/Filters/CommandAlliasFilter.cs
rename to Telegrator/Filters/CommandAliasFilter.cs
diff --git a/Telegrator/Handlers/MessageHandler.cs b/Telegrator/Handlers/MessageHandler.cs
index 6d1176e..06bdb13 100644
--- a/Telegrator/Handlers/MessageHandler.cs
+++ b/Telegrator/Handlers/MessageHandler.cs
@@ -70,7 +70,7 @@ namespace Telegrator.Handlers
suggestedPostParameters, cancellationToken);
///
/// Sends a response message to the current chat.
///
/// The text of the message to send.
/// The parse mode for the message text.
@@ -88,7 +88,7 @@ namespace Telegrator.Handlers
///
/// The cancellation token.
/// The sent message.
- protected async Task Response(
+ protected async Task Responce(
string text,
ParseMode parseMode = ParseMode.None,
ReplyParameters? replyParameters = null,
@@ -104,7 +104,7 @@ namespace Telegrator.Handlers
int? directMessageTopicId = null,
SuggestedPostParameters? suggestedPostParameters = null,
CancellationToken cancellationToken = default)
- => await Container.Response(
+ => await Container.Responce(
text, parseMode, replyParameters,
replyMarkup, linkPreviewOptions,
messageThreadId, entities,
@@ -70,7 +70,7 @@ namespace Telegrator.Handlers
suggestedPostParameters, cancellationToken);
///
- /// Sends a response message to the current chat.
+ /// Sends a responce message to the current chat.
///
/// The text of the message to send.
diff --git a/Telegrator/Handlers/TypesExtensions.cs b/Telegrator/Handlers/TypesExtensions.cs
index f473b02..b4d5477 100644
--- a/Telegrator/Handlers/TypesExtensions.cs
+++ b/Telegrator/Handlers/TypesExtensions.cs
@@ -92,7 +92,7 @@ namespace Telegrator.Handlers
suggestedPostParameters, cancellationToken);
///
/// Sends a response message to the current chat.
///
///
/// The text of the message to send.
@@ -111,7 +111,7 @@ namespace Telegrator.Handlers
///
/// The cancellation token.
/// The sent message.
- public static async Task Response(
+ public static async Task Responce(
this IHandlerContainer container,
string text,
ParseMode parseMode = ParseMode.None,
@@ -138,7 +138,7 @@ namespace Telegrator.Handlers
suggestedPostParameters, cancellationToken);
///
- /// Responnces to message that this CallbackQuery was originated from
+ /// Responces to message that this CallbackQuery was originated from
///
///
///
@@ -158,7 +158,7 @@ namespace Telegrator.Handlers
///
///
///
- public static async Task Response(
+ public static async Task Responce(
this IHandlerContainer container,
string text,
ParseMode parseMode = ParseMode.None,
@@ -92,7 +92,7 @@ namespace Telegrator.Handlers
suggestedPostParameters, cancellationToken);
///
- /// Sends a response message to the current chat.
+ /// Sends a responce message to the current chat.
///
///